@@ -87,7 +87,6 @@ class Tester:
     def evaluate(self, estimator: Estimator) -> List[TestReport]:
         test_reports = []
         samples = estimator.clean_data(self.__samples)
-        logging.info("testing with " + str(len(samples)) + " samples")
         for i in range(0, len(samples)):
             # split test data
             num_train_samples = int(len(samples) * 0.7)
@@ -134,7 +133,6 @@ class ValueRecorder:
 class PvPowerForecast:
 
     def __init__(self, station_id: str, train_dir: str = None):
-        self.__lock = RLock()
         if train_dir is None:
             train_dir = site_data_dir("pv_forecast", appauthor=False)
         self.weather_forecast_service = WeatherStation(station_id)
@@ -160,34 +158,29 @@ class PvPowerForecast:
                 self.__estimator.retrain(samples)
                 self.__date_last_retrain = datetime.now()
                 self.__num_samples_last_retrain = len(samples)
-                if len(samples) < 1000:
-                    test_reports = Tester(samples).evaluate(self.__estimator)
-                    logging.info("prediction model retrained " + reason + " (median deviation: " + str(round(test_reports[int(len(test_reports)*0.5)].score, 1)) + "% -> smaller is better)")
-                else:
-                    logging.info("prediction model retrained " + reason)
+                logging.info("prediction model (" + str(self.__estimator) + ") retrained " + reason)
 
         except Exception as e:
             logging.warning("error occurred retrain prediction model " + str(e))
 
     def current_power_reading(self, real_power: int):
-        with self.__lock:
-            if self.__train_value_recorder.is_expired():
-                logging.info(str(self.__train_value_recorder) + " is expired. generated train data record")
-                try:
-                    if self.__train_value_recorder.average is not None:
-                        weather_sample = self.weather_forecast_service.forecast(self.__train_value_recorder.time)
-                        annotated_sample = LabelledWeatherForecast(self.__train_value_recorder.time,
-                                                                   weather_sample.irradiance,
-                                                                   weather_sample.sunshine,
-                                                                   weather_sample.cloud_cover,
-                                                                   weather_sample.probability_for_fog,
-                                                                   weather_sample.visibility,
-                                                                   self.__train_value_recorder.average)
-                        self.train_log.append(annotated_sample)
-                finally:
-                    self.__train_value_recorder = ValueRecorder()
-                    self.__retrain("on updated train data")
-            self.__train_value_recorder.add(real_power)
+        if self.__train_value_recorder.is_expired():
+            logging.info(str(self.__train_value_recorder) + " is expired. generated train data record")
+            try:
+                if self.__train_value_recorder.average is not None:
+                    weather_sample = self.weather_forecast_service.forecast(self.__train_value_recorder.time)
+                    annotated_sample = LabelledWeatherForecast(self.__train_value_recorder.time,
+                                                               weather_sample.irradiance,
+                                                               weather_sample.sunshine,
+                                                               weather_sample.cloud_cover,
+                                                               weather_sample.probability_for_fog,
+                                                               weather_sample.visibility,
+                                                               self.__train_value_recorder.average)
+                    self.train_log.append(annotated_sample)
+            finally:
+                self.__train_value_recorder = ValueRecorder()
+            self.__retrain("on updated train data")
+        self.__train_value_recorder.add(real_power)
 
     def predict_by_weather_forecast(self, sample: WeatherForecast) -> int:
         return self.__estimator.predict(sample)
